@@ -47,7 +47,12 @@ class BaseContainer(SmartWidget):
       result = dict()
       
       for isY, data in enumerate((("x", "column"), ("y", "row"))):
-         padding = [int(x) for x in self._smartWidgetStyle[f"childPad{data[0]}"].split()] # TODO It can also be a scalar!
+         padKey = f"pad{data[0]}"
+         
+         padding = [int(x) for x in smartWidget._smartWidgetStyle.get(padKey, self._smartWidgetStyle[f"childPad{data[0]}"]).split()]
+         
+         if len(padding) == 1:
+            padding.append(padding[0])
          
          sentinel = getattr(smartWidget, data[1])
          
@@ -62,9 +67,9 @@ class BaseContainer(SmartWidget):
                   sentinel += columnspan - 1
             
             if sentinel == ((self.__rows if isY else self.__columns) - 1):
-               padding[1] = int(self._smartWidgetStyle["childPadx"].split()[0])
+               padding[1] = int(self._smartWidgetStyle["childPadx"].split()[0]) # TODO It can also be a scalar!
          
-         result[f"pad{data[0]}"] = padding
+         result[padKey] = padding
       
       return result
    
